BNode class

Represents a blank node in an RDF graph.

A blank node is an anonymous resource that does not have a URI. It is used to represent complex structures and relationships without assigning a global identifier.

Inheritance

Constructors

BNode([String? id])
Creates a blank node with an optional identifier.

Properties

base ↔ String?
getter/setter pairinherited
hashCode → int
Uses value as the main identifier, useful for saving URIRef type in set.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String
getter/setter pairinherited

Methods

checkUri() → void
Checks valid uri and log relevant information.
inherited
fragment() → String
Extracts fragment after '#' for a valid URI.
inherited
inNamespace(Namespace ns) → bool
Checks if a full URIRef contains the namespace.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
slash(String name) → URIRef
Adds attribute to form a concrete URIRef
inherited
toString() → String
A string representation of this object.
override
updateBase({required String newBase}) → void
Sets a different base with some limitations.
inherited

Operators

operator ==(Object other) → bool
Two URIRef instances are equal if they have the same value/hashcode.
inherited