Namespace class

Implementers

Constructors

Namespace({required String ns})

Properties

hashCode → int
The hash code for this object.
no setterinherited
ns → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uriRef → URIRef?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withAttr(String attr) → URIRef
This is used to further shorten the namespace binding

Operators

operator ==(Object other) → bool
The equality operator.
inherited